<?php
/**
 * The featured layouts
 *
 * @package News
 */

defined( 'WPINC' ) || exit;

/**
 * Class for featured layouts.
 */
class News_Featured_Layouts extends News_Base {

	/**
	 * Current layout.
	 *
	 * @var string
	 */
	public $current = null;

	/**
	 * Hold sections.
	 *
	 * @var array
	 */
	private $sections = null;

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->sections = news_get_settings( 'mts_featured_categories' );
	}

	/**
	 * Render layout
	 */
	public function render() {

		if ( empty( $this->sections ) ) {
			$this->current = array(
				'layout'       => 'default',
				'posts_layout' => 'layout-default',
				'unique_id'    => 'nothing',
				'is_latest'    => true,
			);

			get_template_part( 'template-parts/posts', 'default' );
			return;
		}

		foreach ( $this->sections as $section ) :

			if ( is_paged() ) {
				$this->current = array(
					'layout'    => 'default',
					'category'  => $section['mts_featured_category'],
					'unique_id' => $section['unique_id'],
					'is_latest' => false,
				);
				get_template_part( 'template-parts/posts', 'default' );
				return;
			}

			$section = wp_parse_args( array_filter( $section ), array(
				'blog_layout'                      => '',
				'mts_featured_category_postsnum'   => 3,
				'mts_featured_category_background' => '',
				'mts_featured_category_margin'     => '',
				'mts_featured_category_padding'    => '',
				'unique_id'                        => '',
			) );

			$category     = $section['mts_featured_category'];
			$posts_layout = $section['blog_layout'];

			if ( 'latest' !== $category ) {
				$this->category_posts( $category, $section['mts_featured_category_postsnum'] );
			}

			$layout = $posts_layout;
			if ( 'layout-default' === $posts_layout ) {
				$layout = 'default';
			}

			$this->current = array(
				'layout'       => $layout,
				'category'     => $category,
				'unique_id'    => $section['unique_id'],
				'is_latest'    => 'latest' !== $category,
				'posts_layout' => $posts_layout,
				'posts_count'  => $section['mts_featured_category_postsnum'],
			);
			if ( have_posts() ) {
				get_template_part( 'template-parts/posts', $layout );
			}

		endforeach;
	}

	/**
	 * Genrate post_container classes
	 */
	public function get_post_container_class() {
		$classes   = array();
		$classes[] = 'layout-' . $this->current['unique_id'];
		$classes[] = $this->current['layout'] . '-container';
		$classes[] = 'clearfix';

		echo join( ' ', $classes );
	}

	/**
	 * Set category in main query
	 *
	 * @param  int $category    Category ID.
	 * @param  int $posts_count Number of posts.
	 */
	public function category_posts( $category, $posts_count ) {
		global $wp_query;

		$wp_query = new WP_Query( 'ignore_sticky_posts=1&category_name=' . $category . '&posts_per_page=' . $posts_count );
	}

	/**
	 * Get section title.
	 *
	 * @param int $category Category id or name.
	 */
	public function get_section_title( $category = false ) {
		if ( news_get_settings( 'mts_featured_category_title_' . $this->current['unique_id'] ) ) :
			$category = ! $category ? $this->current['category'] : $category;
		?>
		<div class="title-container title-id-<?php echo $this->current['unique_id']; ?>">
			<?php
			if ( ! $this->current['is_latest'] && 'latest' === $category ) {
				echo '<h3 class="featured-category-title">';
				_e( 'Recent Stories', 'news' );
				echo '</h3></div>';
				return;
			}
			$category_name = news_get_cat_name( $category );
			$category_id   = get_cat_ID( $category_name );
			?>
			<h3 class="featured-category-title"><a href="<?php echo esc_url( get_category_link( $category_id ) ); ?>" title="<?php echo esc_attr( $category_name ); ?>"><?php echo esc_html( $category_name ); ?></a></h3>
		</div>
		<?php
		endif;
	}

	/**
	 * Get more link.
	 */
	public function get_more_link() {

		$is_readmore_enable = news_get_settings( 'post_more_link_' . $this->current['unique_id'] );
		$is_share_enable    = news_get_settings( 'post_share_link_' . $this->current['unique_id'] );

		if ( ! $is_readmore_enable && ! $is_share_enable ) {
			return;
		}

		if ( 'latest' === $this->current['category'] ) {
			$category_name = 'latest';
			$link          = esc_url( trailingslashit( home_url() ) ) . 'page/2';
			$share_link    = esc_url( trailingslashit( home_url() ) );
		} else {
			$category      = $this->current['category'] ? $this->current['category'] : '';
			$category_name = esc_attr( news_get_cat_name( $category ) );
			$category_id   = get_cat_ID( $category_name );
			$link          = esc_url( get_category_link( $category_id ) );
			$share_link    = $link;
		}

		echo '<div class="post-footer">';

		if ( $is_readmore_enable ) {
			printf(
				'<div class="more-link left"><a href="%1$s" title="%2$s">%3$s</a></div>',
				$link,
				$category_name,
				__( 'More Stories on this topic', 'news' )
			);
		}

		if ( $is_share_enable ) {
		?>
		<div class="posts-share right">
			<div class="posts-share-icon"><i class="fa fa-share-alt"></i></div>
			<?php $this->posts_share_popup( $category_name, $share_link ); ?>
		</div>
		<?php
		}

		echo '</div>';

	}

	/**
	 * Get post share buttons.
	 *
	 * @param  string  $category_name.
	 *
	 * @param  string  $share_link.
	 */
	public function posts_share_popup( $category_name, $share_link ) {
	?>

		<div class="popup-overlay"></div>
		<div class="posts-share-popup">

			<?php
			if ( 'latest' === $this->current['category'] ) {
				$args = array(
					'posts_per_page' => 1,
				);
			} else {
				$args = array(
					'category_name'  => $category_name,
					'posts_per_page' => 1,
				);
			}

			$my_query = new WP_Query( $args );

			if ( $my_query->have_posts() ) {
				while ( $my_query->have_posts() ) {

					$my_query->the_post();

					if ( has_post_thumbnail() ) {
						$img     = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
						$img_url = $img[0];
					}

					?>
					<header>
						<i class="fa fa-times"></i>
						<span><?php echo $category_name; ?></span>
						<h3><?php the_title(); ?></h3>
					</header>
					<?php
				}
			}
			?>

			<span class="share-text"><?php _e( 'Share it via...', 'news' ); ?></span>
			<div class="posts-share-buttons">

				<!-- Facebook -->
				<a href="//www.facebook.com/share.php?m2w&s=100&p[url]=<?php echo $share_link; ?>&p[images][0]=<?php echo urlencode( $img_url[0] ); ?>&p[title]=<?php echo urlencode( get_the_title() ); ?>&u=<?php echo $share_link; ?>&t=<?php echo urlencode( get_the_title() ); ?>" class="facebooksharebtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-text"><?php _e( 'Facebook', 'news' ); ?></span></a>

				<!-- Twitter -->
				<?php
				$via = '';
				if ( news_get_settings( 'mts_twitter_username' ) ) {
					$via = '&via=' . news_get_settings( 'mts_twitter_username' );
				}
				?>
				<a href="https://twitter.com/intent/tweet?original_referer=<?php echo $share_link; ?>&text=<?php echo get_the_title(); ?>&url=<?php echo $share_link; ?><?php echo $via; ?>" class="twitterbutton" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-text"><?php _e( 'Twitter', 'news' ); ?></span></a>

				<!-- Pinterest -->
				<a href="http://pinterest.com/pin/create/button/?url=<?php echo $share_link; ?>&media=<?php echo $img_url; ?>&description=<?php the_title(); ?>" class="pinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-text"><?php _e( 'Pinterest', 'news' ); ?></span></a>

			</div>

		</div><!-- .posts-share-popup -->
		<?php
	}

	/**
	 * Get post thumbnail according to layout
	 *
	 * @param  number  Post count.
	 */
	public function get_post_thumbnail( $count = false ) {

		if ( $count > 1 ) {
			echo '<div class="thumb-arrow"><i class="fa fa-caret-right"></i></div>';
			return;
		}

		$default_thumb = 'news-featured';
		?>
		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image post-image-left <?php echo $default_thumb; ?>">
			<div class="featured-thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $default_thumb, array( 'title' => '' ) );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $default_thumb . '.png" alt="' . __( 'No Preview', 'news' ) . '"  class="wp-post-image" />';
				}
				?>
			</div>
		</a>
		<?php
	}

	/**
	 * Get post title
	 *
	 * @param  boolean $meta     Display meta.
	 *
	 * @param  boolean Display review.
	 */
	public function get_post_title( $meta = true ) {
		?>
		<header>
			<h2 class="title front-view-title">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php echo the_title(); ?></a>
			</h2>
			<?php
			if ( $meta ) {
				news_the_post_meta( 'home', $this->current['unique_id'] );
			}

			if ( function_exists( 'wp_review_show_total' ) ) {
				wp_review_show_total( true, 'latestPost-review-wrapper' );
			}
			?>
		</header>
		<?php
	}

	/**
	 * Get sidebar
	 */
	public function get_sidebar() {
		$cat_name = __( 'Latest ', 'news' );
		if ( 'latest' !== $this->current['category'] ) {
			$cat_name = ucwords( news_get_cat_name( $this->current['category'] ) );
		}
		if ( 'default' == $this->current['layout'] ) {
			$this->current['layout'] = 'layout-default';
		}
		?>
		<aside id="sidebar" class="sidebar c-4-12 post-<?php echo $this->current['layout']; ?>" role="complementary" itemscope itemtype="http://schema.org/WPSideBar">
			<?php
			dynamic_sidebar( sanitize_title( strtolower( 'post-' . $this->current['layout'] . $cat_name ) ) );
			?>
		</aside>
		<?php
	}

	/**
	 * Get post pagination
	 */
	public function get_post_pagination() {
		if ( ! $this->current['is_latest'] ) {
			news_pagination( news_get_settings( 'mts_pagenavigation_type' ) );
		}
		wp_reset_query();
	}
}
