<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package News
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function news_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function news_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function news_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function news_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function news_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = news()->get_page_id();

	// Site Background.
	$css['global']['html body, blockquote'] = News_Sanitize::background( news_get_settings( 'mts_background' ) );

	// Top bar Background.
	$css['global']['.top-bar'] = News_Sanitize::background( news_get_settings( 'top_bar_background' ) );

	// Header Background.
	$css['global']['.main-header, #site-header.sticky-navigation-active'] = News_Sanitize::background( news_get_settings( 'header_background' ) );

	// Content Font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'content_font' ) ) );
	// Logo Font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'news_logo' ) ) );
	// Primary Navigation font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'primary_navigation_font' ) ) );
	// Homepage post title font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'home_title_font' ) ) );
	// Pagination.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'pagination_font' ) ) );
	// Breadcrumbs font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'breadcrumb_font' ) ) );
	// Single post title font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_title_font' ) ) );
	// Single Page titles font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_page_titles_font' ) ) );
	// Related Posts Section title font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'related_post_title_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'related_posts_text_font' ) ) );
	// Single subscribe box.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_subscribe_title_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_subscribe_text_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_subscribe_input_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_subscribe_submit_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_authorbox_author_name_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'single_authorbox_text_font' ) ) );
	// Left Sidebar widget title font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'left_sidebar_title_font' ) ) );
	// Sidebar widget title font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_title_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_buttons_font' ) ) );
	// Sidebar widget font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'mts_widget_links' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'default_widget_links' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_url_bigthumb' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_font_bigthumb' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_postinfo_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'sidebar_postinfo_font_bigthumb' ) ) );
	// Tab widget title font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'tabs_title_font' ) ) );
	// Copyrights section font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'fields_font' ) ) );
	// H1 title in the content.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'h6_headline' ) ) );

	news_dynamic_css_skin( $css );
	news_sidebar_position( $css );
	news_header( $css );
	news_sidebar_styling( $css );
	news_post_layouts( $css );
	news_post_pagination( $css );
	news_copyrights( $css );
	news_single( $css );
	news_single_social_buttons( $css );
	news_misc_css( $css );

	return apply_filters( 'news_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function news_dynamic_css_skin( &$css ) {

	// Primary Color.
	$primary_color_scheme = News_Sanitize::color( news_get_settings( 'primary_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.reply a',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.shareit-circular.standard .fa:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#sidebar .widget li a:hover',
		'.title a:hover',
		'#tabber .inside li a:hover',
		'.fn a',
		'.widget .wp_review_tab_widget_content a',
		'.sidebar .wpt_widget_content a',
		'.related-posts .title a:hover',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'#primary-navigation li:hover',
		'.readMore a',
		'blockquote::before',
		'.layout-default .latestPost .post-info a:hover',
		'.breadcrumb .separator',
		'.rank-math-breadcrumb .separator',
		'.single_post .post-info a:hover',
		'.postauthor h5 a:hover',
		'.thumb-arrow',
		'.left-sidebar .widget.widget_nav_menu li a:hover',
		'.left-sidebar .widget.widget_nav_menu li.current-menu-item a',
		'.left-sidebar .widget li a:hover',
		'.left-sidebar .widget li.current-cat a',
		'.widget .sbutton',
		'.tags a',
		'.tagcloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'#sidebar .widget li.verticle-small .post-title a:hover',
		'#copyright-note a:hover',
	);

	$css['global'][ news_implode( $elements ) ]['color'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.layout-1 .latestPost a:hover',
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.widget .wpt_widget_content .tab_title.selected a',
		'.widget .wp_review_tab_widget_content .tab_title.selected a',
	);
	$css['global'][ news_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.single .pagination a:hover .current',
		'a#pull',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.mts-subscribe input[type="submit"]',
		'.widget_product_search button[type="submit"]',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce .bypostauthor:after',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.woocommerce #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.button',
		'.instagram-button a',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.owl-prev:hover, .owl-next:hover',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'#sidebar .widget h3::before',
		'.prev-next .prev a:hover',
		'.prev-next .next a:hover',
		'.pagination .nav-previous a:hover',
		'.pagination .nav-next a:hover',
		'.tags a:hover',
		'.widget #wp-subscribe input.submit',
		'.click-menu-icon span',
	);

	$css['global'][ news_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = $primary_color_scheme;

	// Background Color Important.
	$elements = array(
		'.tagcloud a:hover, #sidebar .widget .tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
	);
	$css['global'][ news_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.flex-control-thumbs .flex-active',
		'#wrapper .cooked-recipe-ingredients .cooked-ingredient-checkbox',
		'#primary-navigation li a:hover',
		'#s:focus',
		'.widget_product_search .search-field:focus',
	);

	$css['global'][ news_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Light color.
	$light_color = color_luminance( $primary_color_scheme, 3 );

	$elements = array(
		'.widget .wpt_widget_content .tab_title.selected a',
		'.widget .wp_review_tab_widget_content .tab_title.selected a',
	);

	$css['global'][ news_implode( $elements ) ]['background-color'] = $light_color;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function news_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = news_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== news_get_settings( 'mts_social_button_position' ) && 'floating' === news_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.right .shareit.shareit-default.floating',
				'.right .shareit.standard.floating',
				'.right .shareit.shareit-circular.floating',
			);

			$css['global'][ news_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ news_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ news_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ news_implode( $shareit_class ) ]['margin-right'] = '50px';
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function news_header( &$css ) {

	// Header.
	$header_class = array(
		'#header',
	);
	news_merge_value( $css['global'][ news_implode( $header_class ) ], News_Sanitize::margin( news_get_settings( 'header_margin' ) ) );
	news_merge_value( $css['global'][ news_implode( $header_class ) ], News_Sanitize::padding( news_get_settings( 'header_padding' ) ) );
	// Header Border.
	$header_border = News_Sanitize::border( news_get_settings( 'header_border' ) );
	$css['global'][ news_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Primary Nav.
	$main_nav_classes = array(
		'#primary-navigation .navigation ul ul a',
		'#primary-navigation .navigation a:hover',
		'#primary-navigation .navigation ul ul a:link',
		'#primary-navigation .navigation ul ul a:visited',
	);
	$css['global'][ news_implode( $main_nav_classes ) ]['color'] = News_Sanitize::color( news_get_settings( 'main_navigation_dropdown_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a:hover']['color'] = News_Sanitize::color( news_get_settings( 'main_navigation_dropdown_hover_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a:hover']['border-color'] = News_Sanitize::color( news_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Header Ad.
	news_merge_value( $css['global']['.widget-header, .small-header .widget-header'], News_Sanitize::margin( news_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = News_Sanitize::color( news_get_settings( 'navigation_ad_background' ) );
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function news_single_social_buttons( &$css ) {

	$social_shadow = news_get_settings( 'social_styling_box_shadow' );

	// Social share.
	$css['global']['.shareit.floating'] = News_Sanitize::background( news_get_settings( 'social_styling_background' ) );
	news_merge_value( $css['global']['.shareit.floating'], News_Sanitize::margin( news_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = News_Sanitize::border( news_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	if ( 0 === $social_shadow ) {
		$css['global']['.shareit.floating']['box-shadow'] = 'none';
	}
	$social_button_layout   = news_get_settings( 'social_button_layout' );
	$social_button_position = news_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function news_sidebar_styling( &$css ) {

	// Left Sidebar.
	news_merge_value( $css['global']['.left-sidebar, .left-sidebar::after'], News_Sanitize::background( news_get_settings( 'left_sidebar_background' ) ) );

	// Title.
	$left_sidebar_title = '.left-sidebar .widget h3, .left-sidebar .widget #wp-subscribe .title';

	$css['global'][ $left_sidebar_title ] = News_Sanitize::background( news_get_settings( 'left_sidebar_title_background' ) );

	news_merge_value( $css['global'][ $left_sidebar_title ], News_Sanitize::margin( news_get_settings( 'left_sidebar_title_margin' ) ) );
	news_merge_value( $css['global'][ $left_sidebar_title ], News_Sanitize::padding( news_get_settings( 'left_sidebar_title_padding' ) ) );

	// Widget.
	news_merge_value( $css['global']['.left-sidebar .widget'], News_Sanitize::background( news_get_settings( 'left_sidebar_widget_background' ) ) );

	news_merge_value( $css['global']['.left-sidebar .widget'], News_Sanitize::margin( news_get_settings( 'left_sidebar_margin' ) ) );
	news_merge_value( $css['global']['.left-sidebar .widget'], News_Sanitize::padding( news_get_settings( 'left_sidebar_padding' ) ) );

	$hover_classes = array(
		'.left-sidebar .widget li.current-cat',
		'.left-sidebar .widget li.current-menu-item',
	);

	$css['global'][ news_implode( $hover_classes ) ]['background'] = News_Sanitize::color( news_get_settings( 'left_sidebar_hover' ) );

	// Left Sidebar border.
	$left_sidebar_border = News_Sanitize::border( news_get_settings( 'left_sidebar_border' ) );
	$css['global']['.left-sidebar .widget'][ $left_sidebar_border['direction'] ] = $left_sidebar_border['value'];

	// Sidebar.
	news_merge_value( $css['global']['#sidebar .widget'], News_Sanitize::background( news_get_settings( 'mts_sidebar_styling_background' ) ) );
	news_merge_value( $css['global']['#sidebar .widget'], News_Sanitize::margin( news_get_settings( 'mts_sidebar_styling_margin' ) ) );
	news_merge_value( $css['global']['#sidebar .widget'], News_Sanitize::padding( news_get_settings( 'mts_sidebar_styling_padding' ) ) );
	// Sidebar border.
	$sidebar_border = News_Sanitize::border( news_get_settings( 'sidebar_styling_border' ) );
	$css['global']['#sidebar .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3, #sidebar .widget #wp-subscribe .title';
	$css['global'][ $sidebar_title ] = News_Sanitize::background( news_get_settings( 'mts_sidebar_title_styling_background' ) );
	news_merge_value( $css['global'][ $sidebar_title ], News_Sanitize::padding( news_get_settings( 'mts_sidebar_title_styling_padding' ) ) );
	news_merge_value( $css['global'][ $sidebar_title ], News_Sanitize::margin( news_get_settings( 'mts_sidebar_title_styling_margin' ) ) );
	// Sidebar Title border.
	$sidebar_title_border = News_Sanitize::border( news_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function news_post_layouts( &$css ) {

	// Post Layouts.
	$features = news_get_settings( 'mts_featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = news_get_settings( 'mts_post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category = get_term_by( 'slug', $category, 'category' );
			if ( $category ) {
				$cat_class = sanitize_key( $category->name );
			}
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = News_Sanitize::background( news_get_settings( 'mts_featured_category_title_background_' . $unique_id ) );
		news_merge_value( $css['global'][ $title_class ], News_Sanitize::margin( news_get_settings( 'mts_featured_category_title_margin_' . $unique_id ) ) );
		news_merge_value( $css['global'][ $title_class ], News_Sanitize::padding( news_get_settings( 'mts_featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = News_Sanitize::border( news_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'mts_featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = News_Sanitize::border( news_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'meta_info_font_' . $unique_id ) ) );

		news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'post_title_font_' . $unique_id ) ) );

		// Border.
		$meta_info_border = News_Sanitize::border( news_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

		// All Posts Margin and Padding.
		news_merge_value( $css['global'][ $post_class ], News_Sanitize::margin( news_get_settings( 'post_margin_' . $unique_id ) ) );
		news_merge_value( $css['global'][ $post_class ], News_Sanitize::padding( news_get_settings( 'post_padding_' . $unique_id ) ) );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function news_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
	);
	news_merge_value( $css['global'][ news_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], News_Sanitize::margin( news_get_settings( 'mts_pagenavigation_margin' ) ) );
	if ( '2' !== news_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ news_implode( $pagination_class ) ]['background-color'] = News_Sanitize::color( news_get_settings( 'mts_pagenavigation_bgcolor' ) );

		$css['global'][ news_implode( $pagination_class_active ) ]['background-color'] = News_Sanitize::color( news_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

		$css['global'][ news_implode( $pagination_class ) ]['color'] = News_Sanitize::color( news_get_settings( 'mts_pagenavigation_color' ) );

		$css['global'][ news_implode( $pagination_class_active ) ]['color'] = News_Sanitize::color( news_get_settings( 'mts_pagenavigation_hover_color' ) );

		news_merge_value( $css['global'][ news_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], News_Sanitize::padding( news_get_settings( 'mts_pagenavigation_padding' ) ) );
	} else {
		$css['global']['#load-posts a']['background-color'] = News_Sanitize::color( news_get_settings( 'load_more_bgcolor' ) );

		$css['global']['#load-posts a:hover']['background-color'] = News_Sanitize::color( news_get_settings( 'load_more_hover_bgcolor' ) );

		$css['global']['#load-posts a']['color'] = News_Sanitize::color( news_get_settings( 'load_more_color' ) );

		$css['global']['#load-posts a:hover']['color'] = News_Sanitize::color( news_get_settings( 'load_more_hover_color' ) );

		news_merge_value( $css['global']['#load-posts a'], News_Sanitize::padding( news_get_settings( 'load_more_padding' ) ) );
	}
	$css['global'][ news_implode( $pagination_class ) ]['border-radius']        = News_Sanitize::size( news_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	$css['global'][ news_implode( $pagination_class_active ) ]['border-radius'] = News_Sanitize::size( news_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	// Pagination border.
	$pagination_border = News_Sanitize::border( news_get_settings( 'pagenavigation_border' ) );
	$css['global'][ news_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];

	// Pagination Alignment.
	$pagenavigation_align = news_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = news_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function news_single( &$css ) {

	// Single, Page, Archive, Search, Category and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
		'.woocommerce .article',
	);

	$css['global'][ news_implode( $page_classes ) ] = News_Sanitize::background( news_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Border Radius.
	news_merge_value( $css['global'][ news_implode( $page_classes ) ], News_Sanitize::margin( news_get_settings( 'mts_single_styling_margin' ) ) );
	news_merge_value( $css['global'][ news_implode( $page_classes ) ], News_Sanitize::padding( news_get_settings( 'mts_single_styling_padding' ) ) );

	// Gutenberg alignfull
	$single_alignfull = News_Sanitize::padding( news_get_settings( 'mts_single_styling_padding' ) );
	$alignfull_left   = - (int) $single_alignfull['padding-right'] . 'px';
	$alignfull_right  = - (int) $single_alignfull['padding-left'] . 'px';

	$css['global']['article .alignfull']['margin-left']  = $alignfull_left;
	$css['global']['article .alignfull']['margin-right'] = $alignfull_right;

	// Single border.
	$single_border = News_Sanitize::border( news_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	// Single border radius.
	$css['global'][ news_implode( $page_classes ) ]['border-radius'] = News_Sanitize::size( news_get_settings( 'single_styling_border_radius' ) . 'px' );

	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'mts_single_meta_info_font' ) ) );

	// Tags Section.
	$css['global']['.tags'] = News_Sanitize::background( news_get_settings( 'single_tags_background' ) );

	news_merge_value( $css['global']['.tags'], News_Sanitize::margin( news_get_settings( 'single_tags_margin' ) ) );
	news_merge_value( $css['global']['.tags'], News_Sanitize::padding( news_get_settings( 'single_tags_padding' ) ) );

	$css['global']['.tags']['border-radius'] = News_Sanitize::size( news_get_settings( 'single_tags_border_radius' ) . 'px' );

	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = News_Sanitize::color( news_get_settings( 'tags_bgcolor' ) );

	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'tags_font' ) ) );

	// Related Posts Section.
	$css['global']['.related-posts'] = News_Sanitize::background( news_get_settings( 'related_posts_background' ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'related_posts_font' ) ) );
	news_map_css_selectors( $css['global'], News_Sanitize::typography( news_get_settings( 'related_posts_meta_font' ) ) );
	news_merge_value( $css['global']['.related-posts'], News_Sanitize::margin( news_get_settings( 'related_posts_margin' ) ) );
	news_merge_value( $css['global']['.related-posts'], News_Sanitize::padding( news_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = News_Sanitize::border( news_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	$css['global']['.related-posts']['border-radius'] = News_Sanitize::size( news_get_settings( 'related_posts_border_radius' ) . 'px' );

	// Related Posts articles.
	$css['global']['.related-posts article'] = News_Sanitize::background( news_get_settings( 'related_article_background' ) );
	news_merge_value( $css['global']['.related-posts article'], News_Sanitize::padding( news_get_settings( 'related_article_padding' ) ) );
	news_merge_value( $css['global']['.related-posts article header'], News_Sanitize::padding( news_get_settings( 'related_article_text_padding' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget #wp-subscribe'] = News_Sanitize::background( news_get_settings( 'single_subscribe_background' ) );
	news_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe'], News_Sanitize::margin( news_get_settings( 'single_subscribe_margin' ) ) );
	news_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe'], News_Sanitize::padding( news_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget #wp-subscribe']['border-radius'] = News_Sanitize::size( news_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ news_implode( $subscribe_input_class ) ]['background-color'] = News_Sanitize::color( news_get_settings( 'single_subscribe_input_background' ) );

	$css['global'][ news_implode( $subscribe_input_class ) ]['height'] = News_Sanitize::size( news_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = News_Sanitize::size( news_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ news_implode( $subscribe_input_class ) ]['border-radius'] = News_Sanitize::size( news_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = News_Sanitize::border( news_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ news_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = News_Sanitize::color( news_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = News_Sanitize::size( news_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = News_Sanitize::border( news_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	news_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], News_Sanitize::padding( news_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = News_Sanitize::background( news_get_settings( 'single_authorbox_background' ) );

	news_merge_value( $css['global']['.postauthor'], News_Sanitize::margin( news_get_settings( 'single_authorbox_margin' ) ) );

	news_merge_value( $css['global']['.postauthor'], News_Sanitize::padding( news_get_settings( 'single_authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = News_Sanitize::size( news_get_settings( 'single_authorbox_border_radius' ) . 'px' );

	$single_authorbox_border = News_Sanitize::border( news_get_settings( 'single_authorbox_border' ) );
	$css['global']['.postauthor'][ $single_authorbox_border ['direction'] ] = $single_authorbox_border ['value'];

	// Author image.
	news_merge_value( $css['global']['.postauthor img'], News_Sanitize::margin( news_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = News_Sanitize::size( news_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Comments Section.
	$css['global']['#comments, #commentsAdd'] = News_Sanitize::background( news_get_settings( 'single_comments_background' ) );
	news_merge_value( $css['global']['#comments'], News_Sanitize::margin( news_get_settings( 'single_comments_margin' ) ) );
	news_merge_value( $css['global']['#comments, #commentsAdd'], News_Sanitize::padding( news_get_settings( 'single_comments_padding' ) ) );

	$css['global']['#comments, #commentsAdd']['border-radius'] = News_Sanitize::size( news_get_settings( 'single_comments_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = news_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ news_implode( $titles_class ) ] = News_Sanitize::background( news_get_settings( 'single_title_background' ) );
	news_merge_value( $css['global'][ news_implode( $titles_class ) ], News_Sanitize::padding( news_get_settings( 'single_title_padding' ) ) );

	// Single title border.
	$single_titles_border = News_Sanitize::border( news_get_settings( 'single_title_border' ) );
	$css['global'][ news_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ news_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ news_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ news_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ news_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ news_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function news_copyrights( &$css ) {

	// Background.
	$css['global']['.copyrights'] = News_Sanitize::background( news_get_settings( 'mts_copyrights_background' ) );

	// Margin and Padding.
	news_merge_value( $css['global']['.copyrights'], News_Sanitize::margin( news_get_settings( 'copyrights_margin' ) ) );
	news_merge_value( $css['global']['.copyrights'], News_Sanitize::padding( news_get_settings( 'copyrights_padding' ) ) );

	// Border.
	$copyrights_border = News_Sanitize::border( news_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function news_misc_css( &$css ) {

	// Show Logo.
	$show_logo = news_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	// Border.
	$top_button_border = News_Sanitize::border( news_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = News_Sanitize::size( news_get_settings( 'top_button_font_size' ) . 'px' );
	news_merge_value( $css['global']['#move-to-top'], News_Sanitize::padding( news_get_settings( 'top_button_padding' ) ) );
	$top_button_position = news_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = News_Sanitize::size( news_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']            = News_Sanitize::color( news_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color']      = News_Sanitize::color( news_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top']['background']       = News_Sanitize::color( news_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background'] = News_Sanitize::color( news_get_settings( 'top_button_background_hover' ) );

	// Instagram full width.
	$padding       = News_Sanitize::padding( news_get_settings( 'mts_sidebar_styling_padding' ) );
	$total_padding = (int) $padding['padding-left'] / 2 + (int) $padding['padding-right'] / 2;

	$classes = array(
		'#sidebar .widget.instagram-widget-wrapper .instagram-posts',
	);

	$css['global'][ news_implode( $classes ) ]['margin-left']  = '-' . $total_padding . 'px';
	$css['global'][ news_implode( $classes ) ]['margin-right'] = '-' . $total_padding . 'px';

	// Single Featured image full width.
	$single_padding = News_Sanitize::padding( news_get_settings( 'mts_single_styling_padding' ) );
	$total_padding  = (int) $single_padding['padding-left'] / 2 + (int) $single_padding['padding-right'] / 2;

	$classes = array(
		'.single-full-header > img',
	);

	$css['global'][ news_implode( $classes ) ]['margin-left']  = '-' . $total_padding . 'px';
	$css['global'][ news_implode( $classes ) ]['margin-right'] = '-' . $total_padding . 'px';

	$css['global'][ news_implode( $classes ) ]['width']     = 'calc(100% + ' . $total_padding * 2 . 'px)';
	$css['global'][ news_implode( $classes ) ]['max-width'] = 'calc(100% + ' . $total_padding * 2 . 'px)';

	if ( ! news_get_settings( 'show_single_featured' ) ) {
		$css['global']['.single-full-header']['margin-top'] = '25px';
	}

	// Sliding menu.
	$menu_classes = array(
		'.left-sidebar-disable .left-sidebar',
		'.left-sidebar-disable .left-sidebar::after',
	);
	$css['@media screen and (max-width:1024px)'][ news_implode( $menu_classes ) ]['margin-left'] = '0px';

	$page_menu_classes = array(
		'.single_page.left-sidebar-disable .left-sidebar',
		'.single_page.left-sidebar-disable .left-sidebar::after',
	);
	$css['@media screen and (max-width:1024px)'][ news_implode( $page_menu_classes ) ]['top'] = '60px';
	$css['@media screen and (max-width:728px)'][ news_implode( $page_menu_classes ) ]['top']  = '160px';
	$css['@media screen and (max-width:480px)'][ news_implode( $page_menu_classes ) ]['top']  = '110px';

}
